//
//  Comment.h
//  sdb
//
//  Created by dka on 09.08.12.
//  Copyright (c) 2012 SAPERION AG. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "User.h"
#import "StatesObject.h"

@interface Annotation : NSObject {
    id delegate;
    SEL selector;
}

@property (nonatomic, strong) NSString *id;
/**
 * The DocumentId this Annotation belongs to
 */
@property (nonatomic, strong) NSString *documentId;
@property (nonatomic, strong) NSString *type;
/**
 * The Annotation itself
 */
@property (nonatomic, strong) NSString *comment;
/**
 * The CreationDate ot the Annotation
 */
@property (nonatomic, strong) NSDate *creationDate;
/**
 * The ID of the User that created this Annoation
 */
@property (nonatomic, strong) NSString *ownerId;
/**
 * The Name of the User that created this Annoation
 */
@property (nonatomic, strong) NSString *ownerName;

/**
 * Inits the Object with the given JSON data
 * @param jsonData the Data of the Object in JSON Format
 */
-(void) fillWithValues:(NSDictionary*)jsonData;

/**
 * Converts the local Object to a NSDictionary so the JSONParser can deserialize it on send
 * @return NSDictionary of the object in key/values
 */
-(NSMutableDictionary*) dictionaryFromObject;

/**
 * Creates a Object with the given JSON Values as separate properties
 * @param jsonData the Data of the Object in JSON Format
 * @return the object
 */
-(Annotation*) initWithDictionary:(NSDictionary*)jsonData;

/**
 * Creates the Object on the Server
 */
-(void) create;

/**
* Loads the OwnerAvatar of the Object with a asyncronous callback to respond to the loaded object
* @param aSelector the SEL that should be called with the response of the external load call
* @param aDelegate the delegate that should be called with the selector
*/
-(void) getOwnerAvatarWithAsyncCallback:(SEL)aSelector onDelegate:(id)aDelegate;

/**
 * Loads the OwnerAvatar of the Object with a syncronous call
 * @return objectImage with the Image
 */
-(ObjectImage*) getOwnerAvatar;

/**
 * Creates a independent copy of the Object
 * @return the object
 */
-(id) copy;

@end
