//
//  Link.h
//  sdb
//
//  Created by dka on 06.08.12.
//  Copyright (c) 2012 SAPERION AG. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "ObjectImage.h"
#import "StatesObject.h"

@interface Link : NSObject {
    id delegate;
    SEL selector;
}

@property (nonatomic, strong) NSString *id;
/**
 * The ID of the Document this Link points to
 */
@property (nonatomic, strong) NSString *documentId;
@property (nonatomic, strong) NSString *type;
/**
 * The ID of the User who created this Link
 */
@property (nonatomic, strong) NSString *ownerId;
/**
 * The Name of the User who created this Link
 */
@property (nonatomic, strong) NSString *ownerName;
/**
 * The Descriptive Name of this Link
 */
@property (nonatomic, strong) NSString *name;
/**
 * The CreadtionDate of this Link
 */
@property (nonatomic, strong) NSDate *creationDate;
/**
 * The Password of this Link if you would like to follow it
 */
@property (nonatomic, strong) NSString *password;
/**
 * The maximum access count of this Link
 */
@property (nonatomic, assign) NSInteger accessLimit;
/**
 * The current access count of this Link
 */
@property (nonatomic, assign) NSInteger currentAccessCount;
/**
 * The expiration Date of this Link
 */
@property (nonatomic, strong) NSDate *expirationDate;
/**
 * The Link itself
 */
@property (nonatomic, strong) NSString *url;

/**
 * Converts the local Object to a NSDictionary so the JSONParser can deserialize it on send
 * @return NSDictionary of the object in key/values
 */
-(NSMutableDictionary*) dictionaryFromObject;

/**
 * Creates the Object on the Server
 * @return jsonData Data of the new Object
 */
-(NSString*) create;

/**
 * Deletes/Terminates the Object on the Server
 */
-(void) delete;

/**
 * Callback Method to be called by the Service on completion of the asyc load process
 * @param OBjectImage comming from the service
 */
-(void) getOwnerAvatarCallback:(ObjectImage*)avatar;

/**
 * Loads the OwnerAvatar of the Object with a asyncronous callback to respond to the loaded object
 * @param aSelector the SEL that should be called with the response of the external load call
 * @param aDelegate the delegate that should be called with the selector
 */
-(void) getOwnerAvatarWithAsyncCallback:(SEL)aSelector onDelegate:(id)aDelegate;

/**
 * Loads the OwnerAvatar of the Object with a syncronous call
 * @return objectImage with the Image
 */
-(ObjectImage*) getOwnerAvatar;

/**
 * Creates a Object with the given JSON Values as separate properties
 * @param jsonData the Data of the Object in JSON Format
 * @return the object
 */
-(Link*) initWithDictionary:(NSDictionary*)jsonData;

/**
 * Creates a independent copy of the Object
 * @return the object
 */
-(id) copy;


@end
