//
//  Project.h
//  sdb
//
//  Created by dka on 31.07.12.
//  Copyright (c) 2012 SAPERION AG. All rights reserved.
//

#import "Folder.h"
#import "Share.h"
#import "StatesObject.h"

#define EMPTY_SPACE_ID @"thisIsAnEmptySpaceThatWasNotSubmittedToService"

@interface Project : StatesObject

@property (nonatomic,strong) NSString* id;
/**
 * The Projects modification Id - Will change on any Object or subObject change
 */
@property (nonatomic,strong) NSString* modificationId;
@property (nonatomic, strong) NSString *type;
/**
 * The OwnerId of the Project
 */
@property (nonatomic, strong) NSString *ownerId;
/**
 * The OwnerName of the Project
 */
@property (nonatomic, strong) NSString *ownerName;
/**
 * The CreationDate of the Project
 */
@property (nonatomic, strong) NSDate *creationDate;
/**
 * The Name of the Project
 */
@property (nonatomic, strong) NSString *name;
/**
 * A Description for the Project
 */
@property (nonatomic, strong) NSString *description;
/**
 * Array of Tags for the Project
 */
@property (nonatomic, strong) NSMutableArray *tags;
/**
 * Array of Rights the Current User has on the Project
 */
@property (nonatomic, strong) NSMutableArray *rights;
/**
 * The Date when the Project was last modified
 */
@property (nonatomic, strong) NSDate *lastModified;
@property (nonatomic, strong) NSMutableString *searchHelperString;

/**
 * Creates the Object on the Server
 * @return jsonData Data of the new Object
 */
-(void) create;

/**
 * Updates the Object on the Server
 */
-(void) save;

/**
 * Deletes/Terminates the Object on the Server
 */
-(void) delete;

/**
 * Creates a Object with the given JSON Values as separate properties
 * @param jsonData the Data of the Object in JSON Format
 * @return the object
 */
-(Project*) initWithDictionary:(NSDictionary*)jsonData ;

/**
 * Converts the local Object to a NSDictionary so the JSONParser can deserialize it on send
 * @return NSDictionary of the object in key/values
 */
-(NSMutableDictionary*) dictionaryFromObject;

/**
 * Creates a new copy of the Object with only parentId and id
 * @return the object
 */
-(id) newWithIDs;

/**
 * Creates a independent copy of the Object
 * @return the object
 */
-(id) copy;

/**
 * Loads the Objects Children from the Server
 * @return NSMutableArray with Children ( Documents / Folders )
 */
-(NSMutableArray*) getChildren;

/**
 * Searchs the Objects Children from the Server
 + @param searchString text to search for on the Server
 * @return NSMutableArray with Children ( Documents / Folders )
 */
-(NSMutableArray*) search:(NSString*)searchString;

/**
 * Loads the Objects Shares from the Server
 * @return NSMutableArray with Shares
 */
-(NSMutableArray*) getShares;

/**
 * Adds a share to the Project
 * @param share The share to create
 */
-(void) addShare:(Share*)share;

/**
 * Deletes a share from the Project
 * @param share The share to delete
 */
-(void) deleteShare:(Share*)share;

/**
 * Updates a share on the Project
 * @param share The share to update
 */
-(void) updateShare:(Share*)share;

/**
 * Downloads a total Folder as zip file
 */
-(NSData*) download;

@end
