//
//  Service.h
//  sdb
//
//  Created by dka on 01.08.12.
//  Copyright (c) 2012 SAPERION AG. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "User.h"
#import "Company.h"
#import "System.h"
#import "Token.h"
#import "ServiceDelegate.h"

@interface Service : NSObject {
    id delegate;
    SEL selector;
    NSTimer *reloadTimer;
    NSString* spaceHash;
}

/**
 * Sets a given URL for the Service and stores it to the Keychain
 */
@property (nonatomic, strong) NSString *urlString;
/**
 * Sets a given Username and stores it to the Keychain
 */
@property (nonatomic, strong) NSString *userName;
/**
 * Sets a given Password and stores it to the Keychain
 */
@property (nonatomic, strong) NSString *password;
@property (nonatomic, strong) Token *token;
/**
 * Tells the Service to include Objects from the RecycleBin
 */
@property (nonatomic, assign) BOOL showsRecycled;
/**
 * Tells the Service to work Offline and use only Objects from the Cache
 */
@property (nonatomic, assign) bool offline;
/**
 * Sets the Debug mode for the Service Logging
 */
@property (nonatomic, assign) bool debugMode;
/**
 * Sets the Cache mode for the Service
 */
@property (nonatomic, assign) bool cacheDisabled;
@property (nonatomic, assign) bool useToken;
@property (nonatomic, assign) bool avatarsLoaded;
@property (nonatomic, strong) id<ServiceErrorDelegate> errorDelegate;
@property (nonatomic, strong) id<ServiceActivityDelegate> activityDelegate;

-(Token*) getToken;

/**
 * Init the timer that watches the Spaces for changes
 * @param aDelegate the delegate to be called if the Spaces change
 * @param aSelector the selector to be called if the Spaces change 
 */
-(void) setSpaceTimerReloadMode:(id)aDelegate withSelector:(SEL)aSelector;

/**
 * Checks if the given values are set for the Service to work
 * @return bool that determines if the Service is configured
 */
-(BOOL) isConfigured;

/**
 * Returns the needed Version of the restService 
 * @return Version of the Service
 */
-(NSString*) getRestAPIVersion;

/**
 * Loads the the Spaces from the Service
 * @return Array of Spaces
 */
-(NSMutableArray*) getSpaces;

/**
 * Loads the current logged in User from the Service
 * @return User that is currently logged in
 */
-(User*) getCurrentUser;

/**
 * Loads the Company Data of the current User
 * @return Company Data of the User
 */
-(Company*) getCompany;

/**
 * Loads the System Information of the current Service
 * @return System Data of the Service
 */
-(System*) getSystem;

/**
 * Loads the System Settings of the current Service
 * @return Settings Data of the Service
 */
-(void) getSettings;

/**
 * Loads the Users of the current Company
 * @return Array of Users
 */
-(NSMutableArray*) getUsers;

/**
 * Reads the Cache Size
 * @return the Cached Objects total size
 */
-(long) getCacheSize;

/**
 * Reads the OfflineCache Size
 * @return the Cached Objects total size
 */
-(long) getOfflineCacheSize;

/**
 * Deletes whole Cache
 */
-(void) clearWholeCache;

/**
 * Checks if CacheSize has reached maximum and performs a partial cleanup. If force = YES the cleanup will be performed and a pauseTimeInterval wont be recognized
 * @param force force?
 */
-(void) checkCacheSize:(bool)force;

/**
 * Gets the Instance of this singleton object and inits it if necessary
 * @return this singleton Object
 */
+(Service *) sharedInstance;

@end
