//
//  Share.h
//  sdb
//
//  Created by dka on 01.08.12.
//  Copyright (c) 2012 SAPERION AG. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "User.h"
#import "StatesObject.h"

@interface Share : NSObject {
    id delegate;
    SEL selector;
}

@property (nonatomic, strong) NSString *id;
@property (nonatomic, strong) NSString *type;
/**
 * The OwnerId of the Share
 */
@property (nonatomic, strong) NSString *ownerId;
/**
 * The OwnerName of the given Share
 */
@property (nonatomic, strong) NSString *ownerName;
/**
 * The CreationDate of the Share
 */
@property (nonatomic, strong) NSDate *creationDate;
/**
 * The Name of the Share
 */
@property (nonatomic, strong) NSString *name;
/**
 * The Id of the Share Receiver
 */
@property (nonatomic, strong) NSString *receiverId;
/**
 * The Name of the Share Receiver
 */
@property (nonatomic, strong) NSString *receiverName;
/**
 * An Array of Rights, the Receiver has on the Share
 */
@property (nonatomic, strong) NSMutableArray *rights;

/**
 * Converts the local Object to a NSDictionary so the JSONParser can deserialize it on send
 * @return NSDictionary of the object in key/values
 */
-(NSMutableDictionary*) dictionaryFromObject;

/**
 * Creates a Object with the given JSON Values as separate properties
 * @param jsonData the Data of the Object in JSON Format
 * @return the object
 */
-(Share*) initWithDictionary:(NSDictionary*)jsonData;

/**
 * Creates a independent copy of the Object
 * @return the object
 */
-(id) copy;

/**
 * Creates a independent copy of the Object with only ti parentID and the id
 * @return the object
 */
-(id) newWithIDs;

/**
 * Loads the OwnerAvatar of the Object with a asyncronous callback to respond to the loaded object
 * @param aSelector the SEL that should be called with the response of the external load call
 * @param aDelegate the delegate that should be called with the selector */
-(void) getReceiverAvatarWithAsyncCallback:(SEL)aSelector onDelegate:(id)aDelegate;

/**
 * Loads the OwnerAvatar of the Object with a syncronous call
 * @return objectImage with the Image
 */
-(ObjectImage*) getReceiverAvatar;


@end
