//
//  User.h
//  sdb
//
//  Created by dka on 01.08.12.
//  Copyright (c) 2012 SAPERION AG. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "ObjectImage.h"


@interface User : NSObject {
    id delegate;
    SEL selector;
}

@property (nonatomic, strong) NSString *id;
@property (nonatomic, strong) NSString *type;
/**
 * The Users Displayname
 */
@property (nonatomic, strong) NSString *displayName;
/**
 * The Users givenname
 */
@property (nonatomic, strong) NSString *firstName;
/**
 * The Users surname
 */
@property (nonatomic, strong) NSString *lastName;
/**
 * The Users email
 */
@property (nonatomic, strong) NSString *email;
/**
 * The Users comany info
 */
@property (nonatomic, strong) NSString *company;
/**
 * The Users rights in an Array
 */
@property (nonatomic, strong) NSMutableArray *rights;
/**
 * The Users States in an Array
 */
@property (nonatomic, strong) NSMutableArray *states;
/**
 * Bool that determines if the User is in the RecycleBin
 */
@property (nonatomic, assign) BOOL isRecyled;
/**
* Bool that determines if the User is ReadOnly
*/
@property (nonatomic, assign) BOOL isReadOnly;
@property (nonatomic, strong) NSString *searchHelperString;

/**
 * Creates a new Instance with the given JSON Values a properties
 * @return a Company
 */
-(User*) initWithDictionary:(NSDictionary*)jsonData;

/**
 * Converts the local Object to a NSDictionary so the JSONParser can deserialize it on send
 * @return NSDictionary of the object in key/values
 */
-(NSMutableDictionary*) dictionaryFromObject;

/**
 * Loads the Avatar of the User with a syncronous call
 * @return objectImage with the Image
 */
-(ObjectImage*) getAvatar;

/**
 * Loads the Avatar of the User with a syncronous call
 * @param useCacheOnly indicates if avatar should be loaded from Cache only
 * @return objectImage with the Image
 */
-(ObjectImage*) getAvatar:(bool)useCacheOnly;

#if TARGET_OS_IPHONE
/**
 * Sets the Avatar of the User with a syncronous call
 * @param Image with the Avatar
 */
-(void) setAvatar:(ObjectImage*)avatar;
#else
-(void) setAvatar:(NSImage*)avatar;
#endif

/**
 * Deletes the Avatar of the User with a syncronous call
 * @param Image with the Avatar
 */
-(void) deleteAvatar;

/**
 * Async callback to be used by the Service class if the load of the Avatar is completed
 * @param Image with the Avatar
 */
-(void) avatarCallBack:(ObjectImage*)avatar;

/**
 * Loads the Avatar of the User with a asyncronous callback to respond to the loaded object
 * @param aSelector the SEL that should be called with the response of the external load call
 * @param aDelegate the delegate that should be called with the selector
 */
-(void) getAvatarWithAsyncCallback:(SEL)aSelector onDelegate:(id)aDelegate;

/**
 * Loads the Avatar of the User with a asyncronous callback to respond to the loaded object
 * @param aSelector the SEL that should be called with the response of the external load call
 * @param aDelegate the delegate that should be called with the selector
 * @param useCacheOnly indicates if avatar should be loaded from Cache only
 */
-(void) getAvatarWithAsyncCallback:(SEL)aSelector onDelegate:(id)aDelegate withUseCacheOnly:(bool)useCacheOnly;

/**
 * Creates a independent copy of the Object
 * @return the object
 */
-(id) copy;

/**
 * Creates a new copy of the Object with only parentId and id
 * @return the object
 */
-(id) newWithIDs;

/**
 * Updates the Object on the Server
 */
-(void) save;

/**
 * Creates the Object on the Server
 */
-(void) create;

/**
 * Deletes/Terminates the User on the Server. The receipentUser receives all Spaces owned by current User
 @param receipentUser the reciepentUser
 */
-(void) delete:(User*)receipentUser;

/**
 * Set a new password for the user
 * @param aPassword the new password
 */
-(void) setPassword:(NSString*)aPassword;

/**
 * Set a new password for the user. Depending on isCurrent, the password is set for the application
 * @param aPassword the new password
 * @param isCurrent is this the currentUser
 * @return was setPassword successfull on service
 */
-(bool) setPasswordExtended:(NSString*)aPassword isCurrentUser:(bool)isCurrent;

@end
