//
//  Version.h
//  sdb
//
//  Created by dka on 01.08.12.
//  Copyright (c) 2012 SAPERION AG. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "User.h"
#import "StatesObject.h"
#import "ObjectData.h"

@interface Version : NSObject {
    id delegate;
    SEL selector;
}

/**
 * The DocuemntId of the Document the Version belongs to
 */
@property (nonatomic, strong) NSString *documentId;
@property (nonatomic, strong) NSString *type;
/**
 * The OwnerId of the Owner
 */
@property (nonatomic, strong) NSString *ownerId;
/**
 * The Name of the Owner
 */
@property (nonatomic, strong) NSString *ownerName;
/**
 * The CreationDate
 */
@property (nonatomic, strong) NSDate *creationDate;
/**
 * The Number of the Version
 */
@property (nonatomic, assign) NSInteger number;
/**
 * The Comment of this Version
 */
@property (nonatomic, strong) NSString  *comment;

/**
 * Converts the local Object to a NSDictionary so the JSONParser can deserialize it on send
 * @return NSDictionary of the object in key/values
 */
-(NSMutableDictionary*) dictionaryFromObject;

/**
 * Creates a Object with the given JSON Values as separate properties
 * @param jsonData the Data of the Object in JSON Format
 * @return the object
 */
-(Version*) initWithDictionary:(NSDictionary*)jsonData;

/**
 * Sets this version as the current Version of the Document
 */
-(void) set;

/**
 * Loads the File of the Object with a syncronous call
 * @return ObjectData with the File
 */
-(ObjectData*) getFile;

/**
 * Loads the File of the Object with a asyncronous callback to respond to the loaded object
 * @param selector the SEL that should be called with the response of the external load call
 * @param aDelegate the delegate that should be called with the selector
 */
-(void) getFileWithAsyncCallback:(SEL)aSelector onDelegate:(id)aDelegate;

/**
 * Loads the Rendition of the Object with a syncronous call
 * @return ObjectData with the Rendition
 */
-(ObjectData*) getRendition;

/**
 * Loads the Rendition of the Object with a asyncronous callback to respond to the loaded object
 * @param selector the SEL that should be called with the response of the external load call
 * @param aDelegate the delegate that should be called with the selector
 */
-(void) getRenditionWithAsyncCallback:(SEL)aSelector onDelegate:(id)aDelegate;

/**
 * Loads the OwnerAvatar of the Object with a asyncronous callback to respond to the loaded object
 * @param aSelector the SEL that should be called with the response of the external load call
 * @param aDelegate the delegate that should be called with the selector
 */
-(void) getOwnerAvatarWithAsyncCallback:(SEL)aSelector onDelegate:(id)aDelegate;

/**
 * Loads the OwnerAvatar of the Object with a syncronous call
 * @return objectImage with the Image
 */
-(ObjectImage*) getOwnerAvatar;

/**
 * Creates a independent copy of the Object
 * @return the object
 */
-(id) copy;

@end
