//
//  restObject.h
//  sdb
//
//  Created by dka on 25.07.12.
//  Copyright (c) 2012 SAPERION AG. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "StatesObject.h"

@interface restObject : StatesObject


@property (nonatomic,strong) NSString* id;
/**
 * The Objects modification Id - Will change on any Object or subObject change
 */
@property (nonatomic,strong) NSString* modificationId;
@property (nonatomic, strong) NSString *type;
/**
 * The ID of the User who owns this Object
 */
@property (nonatomic, strong) NSString *ownerId;
/**
 * The Name of the User who owns this Object
 */
@property (nonatomic, strong) NSString *ownerName;
/**
 * The CreationDate of this Object
 */
@property (nonatomic, strong) NSDate *creationDate;
/**
 * The Name of this Object
 */
@property (nonatomic, strong) NSString *name;
/**
 * The Description of this Object
 */
@property (nonatomic, strong) NSString *description;
/**
 * An Array of tags of this Object
 */
@property (nonatomic, strong) NSMutableArray *tags;
/**
 * The ID of the Project this Object resides in
 */
@property (nonatomic, strong) NSString *projectId;
/**
 * The ID of the Parent Folder/Project this Object resides in
 */
@property (nonatomic, strong) NSString *parentId;
/**
 * The Date of the last modification of this Object
 */
@property (nonatomic, strong) NSDate *lastModified;
@property (nonatomic, strong) NSMutableString *searchHelperString;

/**
 * Fills the Objects variables with the given Values in JSON Format
 * @param objectToFill the object to be filled
 * @param jsonData Data from a NSURLConnection as NSDictionary in JSON Format
 * @return the filled Object
 */
-(id) fillObject:(id)objectToFill withValues:(NSDictionary*)jsonData;

/**
 * Creates the Object on the Server
 * @return jsonData Data of the new Object
 */
-(NSString*) create;

/**
 * Updates the Object on the Server
 */
-(void) save;

/**
 * Deletes/Terminates the Object on the Server
 */
-(void) delete;

/**
 * Converts the local Object to a NSDictionary so the JSONParser can deserialize it on send
 * @return NSDictionary of the object in key/values
 */
-(NSMutableDictionary*) dictionaryFromObject;

/**
 * Creates a new copy of the Object with only parentId and id
 * @return the object
 */
-(id) newWithIDs;

/**
 * Creates a independent copy of the Object
 * @return the object
 */
-(id) copy;

@end
