//
//  SettingsProvider.h
//  sdb
//
//  Created by Daniel Kalwitzki on 10.03.13.
//  Copyright (c) 2013 SAPERION AG. All rights reserved.
//

#import <Foundation/Foundation.h>

@interface SettingsProvider : NSObject {
    NSMutableDictionary *settings;
}

typedef enum SettingTypes {
    SettingType_autoWlans = 1,
    SettingType_url = 2,
    SettingType_systemSettings = 3,
    SettingType_userSettings = 4
} SettingType;

@property (nonatomic, strong) NSString *filePath;

/**
 * Gets a Settings Array from the SettingsStore
 * @param aKey the SettingType for the Setting to be collected
 * @return the Value Array to be collected
 */
-(NSMutableArray*) arrayForSettingType:(SettingType)aKey;

/**
 * Gets a Settings Dictionary from the SettingsStore
 * @param aKey the SettingType for the Setting to be collected
 * @return the Value Dictionary to be collected
 */
-(NSMutableDictionary*) dictionaryForSettingType:(SettingType)aKey;
/**
 * Gets a Settings Object from the SettingsStore
 * @param aKey the SettingType for the Setting to be collected
 * @return the Object to be collected
 */
-(id)objectForSettingType:(SettingType)aKey;

/**
 * Gets a Settings Value from the SettingsStore
 * @param aKey the SettingType for the Setting to be collected
 * @return the value to be collected
 */
-(id)valueForSettingType:(SettingType)aKey;

/**
 * Gets a Setting from the SettingsStore
 * @param aKey the SettingType for the Setting to be collected
 * @return the value to be collected
 */
-(id)valueForUndefinedSettingType:(SettingType)aKey;

/**
 * sets a Setting to the SettingsStore
 * @param aKey the SettingType for the Setting to be set
* @param value the value to be set
 */
-(void)setValue:(id)value forSettingType:(SettingType)aKey;

/**
 * removes all Settings from the SettingsStore
 */
-(void)removeAllObjects;

/**
 * removes a Setting from the SettingsStore
 * @param aKey the SettingType for the Setting to remove
 */
-(void)removeObjectForSettingType:(SettingType)aKey;

/**
 * puts the System Settings into the SettingsStore
 * @param dict the Dictionary with System Settings
 */
-(void) setSystemSettings:(NSMutableDictionary*)dict;

/**
 * puts the USer Settings into the SettingsStore
 * @param dict the Dictionary with User Settings
 */
-(void) setUserSettings:(NSMutableDictionary*)dict;

/**
 * Initalizes the Class as Singleton
 * @return the Singleton of the Class
 */
+ (SettingsProvider *) sharedInstance;

@end
