//
//  TimerCentrator.h
//  sdb
//
//  Created by Daniel Kalwitzki on 11.03.13.
//  Copyright (c) 2013 SAPERION AG. All rights reserved.
//

#import <Foundation/Foundation.h>

@interface TimerCentralizer : NSObject

/**
 * An Array of Timers the Centralizer handles
 */
@property (nonatomic, strong) NSMutableArray *timers;
@property (nonatomic, strong) NSTimer *localtimer;
@property (nonatomic, strong) NSNumber *timeIntervall;
@property (nonatomic, assign) bool debugMode;


/**
 * Tells the Timer to fire directly
 */
-(void) runNow;

/**
 * Adds a Timer to be handled by the Centralizer
 * @param selector the selector to be called by the Timer
 * @param delegate the delegate to be called by the Timer
 * @param seconds time in seconds until the Timer fires
 * @param conClass delegate where the condition can be called
 * @param conSelector selector on the class where the Condition can be called
 */
-(void) addTimer:(NSString*)selector onDelegate:(id)delegate withInterval:(int)seconds conditionalDelegate:(id)conClass conditionalSelector:(NSString*)conSelector;

/**
 * Adds a Timer to be handled by the Centralizer
 * @param selector the selector to be called by the Timer
 * @param delegate the delegate to be called by the Timer
 * @param seconds time in seconds until the Timer fires
 */
-(void) addTimer:(NSString*)selector onDelegate:(id)delegate withInterval:(int)seconds;

/**
 * Initializes the Class as singleton
 * @return the singelton class
 */
+ (TimerCentralizer *) sharedInstance;

@end
