//
//  Document.h
//  sdb
//
//  Created by dka on 25.07.12.
//  Copyright (c) 2012 SAPERION AG. All rights reserved.
//

#import "restObject.h"
#import "Link.h"
#import "Annotation.h"
#import "ObjectData.h"

@interface Document : restObject {
    SEL thumbsSelector;
    id thumbsDelegate;
    SEL fileSelector;
    id fileDelegate;
    SEL renditionSelector;
    id renditionDelegate;
    SEL previewSelector;
    id previewDelegate;
}

/**
 * The Version of this Document
 */
@property (nonatomic, assign) NSInteger versionNumber;
@property (nonatomic, assign) NSInteger pages;
/**
 * The Size of this Document in KB
 */
@property (nonatomic, assign) NSInteger size;
/**
 * The MimeType of this Document
 */
@property (nonatomic, strong) NSString *mimeType;
/**
 * The ContentHash of this Document as MD5
 */
@property (nonatomic, strong) NSString *hash;

/**
 * Creates the Object on the Server
 * @return jsonData Data of the new Object
 */
-(Document*) create;

/**
 * Creates a Object with the given JSON Values as separate properties
 * @param jsonData the Data of the Object in JSON Format
 * @return the object
 */
-(Document*) initWithDictionary:(NSDictionary*)jsonData;

/**
 * Loads the Preview of the Object with a syncronous call
 * @return objectImage with the Image
 */
-(ObjectImage*) getPreview;

/**
 * Async Callback Method for Caching on the Preview of the Object with a asynchronous call
 * @return objectImage with the Image
 */
-(void) previewCallback:(ObjectImage*)preview;

/**
 * Loads the Preview of the Object with a asyncronous callback to respond to the loaded object
 * @param selector the SEL that should be called with the response of the external load call
 * @param aDelegate the delegate that should be called with the selector 
 */
-(void) getPreviewWithAsyncCallback:(SEL)selector onDelegate:(id)aDelegate;

///**
// * Loads the Thumbnail of the Object with a syncronous call
// * @return ObjectImage with the Image
// */
//-(ObjectImage*) getThumb;
//
///**
// * Loads the Thumbnails of the Object with a syncronous call
// * @return Array of images
// */
//-(NSMutableArray*) getThumbs:(NSMutableArray*)pages;
//
///**
// * Async Callback Method for Caching on the Thumbs of the Object with a asynchronous call
// * @return objectImage with the Image
// */
//-(void) thumbsCallback:(NSData*)thumb;
//
///**
// * Loads the Thumbs of the Object with a asyncronous callback to respond to the loaded object
// * @param selector the SEL that should be called with the response of the external load call
// * @param aDelegate the delegate that should be called with the selector
// */
//-(void) getThumbWithAsyncCallback:(SEL)selector onDelegate:(id)aDelegate;

/**
 * Loads the Objects Links from the Server
 * @return NSMutableArray with Links
 */
-(NSMutableArray*) getLinks;

/**
 * Loads the Objects Versions from the Server
 * @return NSMutableArray with Versions
 */
-(NSMutableArray*) getVersions;

/**
 * Loads the Objects Activities from the Server
 * @return NSMutableArray with Activities
 */
-(NSMutableArray*) getActivities;

/**
 * Loads the Objects Comments from the Server
 * @return NSMutableArray with Comments
 */
-(NSMutableArray*) getComments;

/**
 * Loads the File of the Object with a syncronous call
 * @return ObjectData with the File
 */
-(ObjectData*) getFile;

/**
 * Loads the File of the Object with a syncronous call if not current version
 * @return ObjectData with the File
 */
-(ObjectData*) getFileVersioned;

/**
 * Async Callback Method for Caching on the File of the Object with a asynchronous call
 * @return objectData with the File
 */
-(void) fileCallback:(ObjectData*)file;

/**
 * Loads the File of the Object with a asyncronous callback to respond to the loaded object
 * @param selector the SEL that should be called with the response of the external load call
 * @param aDelegate the delegate that should be called with the selector
 */
-(void) getFileWithAsyncCallback:(SEL)aSelector onDelegate:(id)aDelegate;

/**
 * Loads the File of the Object with a asyncronous callback to respond to the loaded object if not current version
 * @param selector the SEL that should be called with the response of the external load call
 * @param aDelegate the delegate that should be called with the selector
 */
-(void) getFileVersionedWithAsyncCallback:(SEL)aSelector onDelegate:(id)aDelegate;

/**
 * Sets the File of the Object
 * @param file the FileData to be set
 */
-(void) setFile:(NSData*)file;

/**
 * Loads the Rendition of the Object with a syncronous call
 * @return ObjectData with the Rendition
 */
-(ObjectData*) getRendition;

/**
 * Async Callback Method for Caching on the Rendition of the Object with a asynchronous call
 * @return objectData with the Rendition
 */
-(void) renditionCallback:(ObjectData*)rendition;

/**
 * Loads the Rendition of the Object with a asyncronous callback to respond to the loaded object
 * @param selector the SEL that should be called with the response of the external load call
 * @param aDelegate the delegate that should be called with the selector
 */
-(void) getRenditionWithAsyncCallback:(SEL)aSelector onDelegate:(id)aDelegate;

/**
 * Sets the Rendition of the Object
 * @param file the FRenditionData to be set
 */
-(void) setRendition:(NSData*)file;

/**
 * Detemines if the Viewer is able to display this Documents File native
 * @return BOOL value that detemines if the Viewer is able to display this Documents File native
 */
-(BOOL) isViewerSupported;

/**
 * Detemines if the Viewer should display this Documents File native
 * @return BOOL value that detemines if the Viewer should display this Documents File native
 */
-(BOOL) isViewerNice;

@end
