//
//  Util.h
//  iSAPERIONbeta
//
//  Created by ris on 04.05.12.
//  Copyright (c) 2012 SAPERION AG. All rights reserved.
//

#import <Foundation/Foundation.h>

typedef enum StringFilterModes{
    STRING_FILTER_MODE_NONE = 1,
    STRING_FILTER_MODE_INT = 2,
    STRING_FILTER_MODE_STRING = 3
} StringFilterMode;

typedef enum DeviceTypes{
    DEVICE_TYPE_IPAD    = 100,
    DEVICE_TYPE_IPHONE  = 200
} DeviceType;

typedef enum DeviceOrientations{
    DEVICE_ORIENTATION_LANDSCAPE    = 1,
    DEVICE_ORIENTATION_PORTRAIT     = 2
} DeviceOrientation;

typedef enum DeviceTypeOrientations{
    DEVICE_TYPEORIENTATION_IPAD_LANDSCAPE   = 101,
    DEVICE_TYPEORIENTATION_IPAD_PORTRAIT    = 102,
    DEVICE_TYPEORIENTATION_IPHONE_LANDSCAPE = 201,
    DEVICE_TYPEORIENTATION_IPHONE_PORTRAIT  = 202
} DeviceTypeOrientation;

@interface Util : NSObject


/**
 @return mime-type for the given file-type
 */
+ (NSString *) getMimefromFilename:(NSString *)fileName;

/**
 @return true if string original contains substring, false if not
 */
+ (BOOL) substringCheck:(NSString *)aOriginal forSubstring:(NSString *)substring;

/**
 * Generates a string with random letters with given length
 * @param length the length of the String
 * @return the generated string
 */
+ (NSString*) generateRandomString: (int) length;

/**
 * Generates a wellformed String with Datasize depending on size
 * @param size the size in Bytes
 * @return the wellformed String
 */
+ (NSString*) wellformedDataSize:(float) size;


/**
 * Filters the given String that result only contains Chars of given CharSet
 * @param unfilteredString th unfiltered String
 * @param allowedChars the allowed chars
 * @return the filteredString
 */
+ (NSString*) filterString:(NSString*)unfilteredString withAllowedChars:(NSCharacterSet*)allowedChars;

/**
 * Filters the given String that result doesn't contain Chars of given CharSet
 * @param unfilteredString th unfiltered String
 * @param notAllowedChars the allowed chars
 * @return the filteredString
 */
+ (NSString*) filterString:(NSString*)unfilteredString withNotAllowedChars:(NSCharacterSet*)notAllowedChars;

/**
 * Filters the given String by given Mode
 * @param unfilteredString th unfiltered String
 * @param filterMode the mode
 * @return the filteredString
 */
+ (NSString*) filterString:(NSString*)unfilteredString withFilterMode:(StringFilterMode)filterMode;

+(DeviceType) deviceType;
+(DeviceOrientation) deviceOrientation;
+(DeviceTypeOrientation) deviceTypeOrientation;
@end
